@@ -55,6 +55,9 @@
 #if defined(HAVE_MLX5DV)
 #include <infiniband/mlx5dv.h>
 #endif
+#if defined(HAVE_HNSDV)
+#include <infiniband/hnsdv.h>
+#endif
 #include <rdma/rdma_cma.h>
 #include <stdint.h>
 #if defined(__FreeBSD__)
@@ -132,6 +135,13 @@
 
 #define MASK_IS_SET(mask, attr)      (((mask)&(attr))!=0)
 
+#define MAX(a, b) \
+	({ \
+		typeof(a) _a = (a); \
+		typeof(b) _b = (b); \
+		_a > _b ? _a : _b; \
+	})
+
 /******************************************************************************
  * Perftest resources Structures and data types.
  ******************************************************************************/
@@ -165,9 +175,11 @@ struct pingpong_context {
 	struct mlx5dv_mkey			**mkey;
 	struct mlx5dv_dek			**dek;
 	#endif
-	struct ibv_comp_channel			*channel;
+	struct ibv_comp_channel			*recv_channel;
+	struct ibv_comp_channel			*send_channel;
 	struct ibv_pd				*pd;
 	struct ibv_mr				**mr;
+	struct ibv_mr				*null_mr;
 	struct ibv_cq				*send_cq;
 	struct ibv_cq				*recv_cq;
 	void					**buf;
@@ -195,7 +207,6 @@ struct pingpong_context {
 	uint64_t				send_qp_buff_size;
 	uint64_t				flow_buff_size;
 	int					tx_depth;
-	int					huge_shmid;
 	uint64_t				*scnt;
 	uint64_t				*ccnt;
 	int					is_contig_supported;
@@ -216,6 +227,7 @@ struct pingpong_context {
 	struct ibv_xrcd				*xrc_domain;
 	int 					fd;
 	#endif
+	struct memory_ctx			*memory;
 };
 
  struct pingpong_dest {
@@ -251,6 +263,19 @@ int check_add_port(char **service,int port,
 				   struct addrinfo *hints,
 				   struct addrinfo **res);
 
+/* sockaddr_set_port
+ *
+ * Description : Initialize port for given sockaddr structure
+ *
+ * Parameters :
+ *	service - an empty char** to contain the service name.
+ *  port - The selected port on which the server will listen.
+ *  sin - sockaddr params for the connection.
+ *
+ * Return Value : SUCCESS, FAILURE.
+ */
+int sockaddr_set_port(struct sockaddr *sin,int port);
+
 /* ctx_find_dev
  *
  * Description : Returns the device corresponding to ib_devname
@@ -495,7 +520,8 @@ void ctx_set_send_wqes(struct pingpong_context *ctx,
  *
  * Description :
  *
- *	Prepare the receives work request templates for all QPs in SEND receive test.
+ *	Prepare the receives work request templates for all QPs in SEND and
+ *	WRITE_IMM receive test.
  *
  * Parameters :
  *
@@ -625,6 +651,19 @@ int run_iter_bi(struct pingpong_context *ctx,struct perftest_parameters *user_pa
  */
 int run_iter_lat_write(struct pingpong_context *ctx,struct perftest_parameters *user_param);
 
+/* run_iter_lat_write_imm
+ *
+ * Description :
+ *
+ *  This is the latency test function for WRITE_IMM verb.
+ *
+ * Parameters :
+ *
+ *	ctx     - Test Context.
+ *	user_param  - user_parameters struct for this test.
+ */
+int run_iter_lat_write_imm(struct pingpong_context *ctx,struct perftest_parameters *user_param);
+
 /* run_iter_lat
  *
  * Description :
@@ -716,6 +755,7 @@ static __inline int ctx_notify_events(struct ibv_comp_channel *channel)
 		return 1;
 	}
 
+	//coverity[uninit_use_in_call]
 	ibv_ack_cq_events(ev_cq,1);
 
 	if (ibv_req_notify_cq(ev_cq, 0)) {
@@ -743,6 +783,40 @@ static __inline void increase_rem_addr(struct ibv_send_wr *wr,int size,uint64_t
 	}
 }
 
+/*
+ * Block until any event (send or receive) is available, and rearm the
+ * appropriate completion channel.
+ */
+static __inline int ctx_notify_send_recv_events(struct pingpong_context *ctx)
+{
+	fd_set rfds;
+
+	FD_ZERO(&rfds);
+	FD_SET(ctx->recv_channel->fd, &rfds);
+	FD_SET(ctx->send_channel->fd, &rfds);
+
+	if (select(MAX(ctx->recv_channel->fd,
+		       ctx->send_channel->fd) + 1,
+		   &rfds, NULL, NULL, NULL) == -1) {
+		fprintf(stderr, "Failed to get completion events\n");
+		return FAILURE;
+	}
+
+	if (FD_ISSET(ctx->recv_channel->fd, &rfds) &&
+	    ctx_notify_events(ctx->recv_channel)) {
+		fprintf(stderr,"Failed to notify receive events to CQ\n");
+		return FAILURE;
+	}
+
+	if (FD_ISSET(ctx->send_channel->fd, &rfds) &&
+	    ctx_notify_events(ctx->send_channel)) {
+		fprintf(stderr,"Failed to notify send events to CQ\n");
+		return FAILURE;
+	}
+
+	return SUCCESS;
+}
+
 /* increase_loc_addr.
  *
  * Description :
@@ -795,13 +869,13 @@ int check_packet_pacing_support(struct pingpong_context *ctx);
 #endif
 
 int create_reg_qp_main(struct pingpong_context *ctx,
-		struct perftest_parameters *user_param, int i, int num_of_qps);
+		struct perftest_parameters *user_param, int i);
 
 int create_qp_main(struct pingpong_context *ctx,
-		struct perftest_parameters *user_param, int i, int num_of_qps);
+		struct perftest_parameters *user_param, int i);
 
 int modify_qp_to_init(struct pingpong_context *ctx,
-                struct perftest_parameters *user_param, int qp_index, int num_of_qps);
+        struct perftest_parameters *user_param, int qp_index);
 
 
 /* create_single_mr
